@@ -25,9 +25,11 @@
 #endif
 
 #include <gio/gio.h>
+#include <amtk/amtk-types.h>
 
 G_BEGIN_DECLS
 
+_AMTK_EXTERN
 void	amtk_action_map_add_action_entries_check_dups	(GActionMap         *action_map,
 							 const GActionEntry *entries,
 							 gint                n_entries,
